@@ -1,3 +1,5 @@
+from pytz import common_timezones
+
 from django import forms
 
 # import models
@@ -6,6 +8,11 @@ from userextensions.models import (UserPreference, ServiceAccount)
 
 class UserPreferenceForm(forms.ModelForm):
     """ Form class used to add/edit UserPreference objects """
+    timezone = forms.ChoiceField(choices=[(i, i) for i in common_timezones],
+                                 widget=forms.Select(attrs={'class': 'form-control'}),
+                                 required=False,
+                                 label='Timezone')
+
     class Meta:
         model = UserPreference
         exclude = ['created_at', 'updated_at', 'user']
@@ -13,6 +20,9 @@ class UserPreferenceForm(forms.ModelForm):
             'recents_count': forms.NumberInput(attrs={'class': 'form-control'}),
             'page_refresh_time': forms.NumberInput(attrs={'class': 'form-control'}),
             'theme': forms.Select(attrs={'class': 'form-control'}),
+            # 'timezone': forms.ChoiceField(choices=[(i, i) for i in common_timezones],
+            #                               attrs={'class': 'form-control'}),
+            'help_text_enabled': forms.CheckboxInput(attrs={'class': 'form-control'}),
             'start_page': forms.TextInput(attrs={'class': 'form-control'}),
         }
 
